@@ -37,13 +37,13 @@ email                : markey@web.de
 #include <tqtimer.h>
 #include <tqtooltip.h>        //analyzer tooltip
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
 #include <kurldrag.h>
-#include <kwin.h>            //eventFilter()
+#include <twin.h>            //eventFilter()
 
 #include <kimageeffect.h>
 
@@ -130,7 +130,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
         //NOTE we use a layout for the buttons so resizing will be possible
         m_pFrameButtons = createWidget<TQHBox>( TQRect(0, 118, 311, 22), this );
 
-        KActionCollection *ac =Amarok::actionCollection();
+        TDEActionCollection *ac =Amarok::actionCollection();
 
         //FIXME change the names of the icons to reflect kde names so we can fall back to them if necessary
                          new NavButton( m_pFrameButtons, "prev", ac->action( "prev" ) );
@@ -251,7 +251,7 @@ void PlayerWidget::setScroll( const TQStringList &list )
     }
 
     //FIXME empty TQString would crash due to NULL Pixmaps
-    if( text.isEmpty() ) text = i18n( "Please report this message to amarok@kde.org, thanks!" );
+    if( text.isEmpty() ) text = i18n( "Please report this message to trinity-devel@lists.pearsoncomputing.net, thanks!" );
 
     TQFont font( m_pScrollFrame->font() );
     TQFontMetrics fm( font );
@@ -440,7 +440,7 @@ void PlayerWidget::determineAmarokColors() //static
 
     (!AmarokConfig::schemeKDE()
         ? AmarokConfig::playlistWindowBgColor()
-        : KGlobalSettings::highlightColor()
+        : TDEGlobalSettings::highlightColor()
       ).getHsv( &hue, &s, &v );
 
     using namespace Amarok::ColorScheme;
@@ -455,7 +455,7 @@ void PlayerWidget::determineAmarokColors() //static
     //TODO schemes that have totally different active/inactive decoration colours need to be catered for too!
     if ( AmarokConfig::schemeKDE() ) {
         int h;
-        KGlobalSettings::activeTitleColor().getHsv( &h, &s, &v );
+        TDEGlobalSettings::activeTitleColor().getHsv( &h, &s, &v );
         if( TQABS( hue - h ) > 120 )
            hue = h;
     }
@@ -597,25 +597,25 @@ bool PlayerWidget::event( TQEvent *e )
 
             if( info.mappingState() == NET::Withdrawn )
             {
-                //extern Atom qt_wm_state; //XAtom defined by TQt
+                //extern Atom tqt_wm_state; //XAtom defined by TQt
 
                 //TODO prevent the active Window flicker from playlist to player window please!
                 //TODO look at code for TQWidget::show();
 
-                //XDeleteProperty( qt_xdisplay(), id, qt_wm_state );
+                //XDeleteProperty( tqt_xdisplay(), id, tqt_wm_state );
 
                 //parentWidget()->show();
-                //if( !parentWidget()->isShown() ) XMapWindow( qt_xdisplay(), id );
+                //if( !parentWidget()->isShown() ) XMapWindow( tqt_xdisplay(), id );
 //                 unsigned long data[2];
 //                 data[0] = (unsigned long) NormalState;
 //                 data[1] = (unsigned long) None;
 //
-//                 XChangeProperty( qt_xdisplay(), id, qt_wm_state, qt_wm_state, 32,
+//                 XChangeProperty( tqt_xdisplay(), id, tqt_wm_state, tqt_wm_state, 32,
 //                      PropModeReplace, (unsigned char *)data, 2);
 //
 //                 KWin::clearState( id, NET::Hidden );
 //
-//                 XMapWindow( qt_xdisplay(), id );
+//                 XMapWindow( tqt_xdisplay(), id );
 //
                 //KWin::deIconifyWindow( id, false );
                 parentWidget()->show();
@@ -849,7 +849,7 @@ void PlayerWidget::slotShowEqualizer( bool show ) //SLOT
 
 #include <kiconeffect.h>
 #include <kimageeffect.h>
-NavButton::NavButton( TQWidget *parent, const TQString &icon, KAction *action )
+NavButton::NavButton( TQWidget *parent, const TQString &icon, TDEAction *action )
     : TQToolButton( parent )
     , m_glowIndex( 0 )
 {
@@ -857,12 +857,12 @@ NavButton::NavButton( TQWidget *parent, const TQString &icon, KAction *action )
     setWFlags( TQt::WNoAutoErase );
 
     TQPixmap pixmap( getPNG( "b_" + icon ) );
-    KIconEffect ie;
+    TDEIconEffect ie;
 
     // Tint icon blueish for "off" state
-    m_pixmapOff = ie.apply( pixmap, KIconEffect::Colorize, 0.5, TQColor( 0x30, 0x10, 0xff ), false );
+    m_pixmapOff = ie.apply( pixmap, TDEIconEffect::Colorize, 0.5, TQColor( 0x30, 0x10, 0xff ), false );
     // Tint gray and make pseudo-transparent for "disabled" state
-    m_pixmapDisabled = ie.apply( pixmap, KIconEffect::ToGray, 0.7, TQColor(), true );
+    m_pixmapDisabled = ie.apply( pixmap, TDEIconEffect::ToGray, 0.7, TQColor(), true );
 
     int r = 0x20, g = 0x10, b = 0xff;
     float percentRed = 0.0;
@@ -871,8 +871,8 @@ NavButton::NavButton( TQWidget *parent, const TQString &icon, KAction *action )
     for ( int i = 0; i < NUMPIXMAPS; i++ ) {
         TQImage img = pixmap.convertToImage();
         temp = KImageEffect::channelIntensity( img, percentRed, KImageEffect::Red );
-        temp = ie.apply( temp, KIconEffect::Colorize, 1.0, TQColor( r, 0x10, 0x30 ), false );
-        temp = ie.apply( temp, KIconEffect::Colorize, 1.0, TQColor( r, g, b ), false );
+        temp = ie.apply( temp, TDEIconEffect::Colorize, 1.0, TQColor( r, 0x10, 0x30 ), false );
+        temp = ie.apply( temp, TDEIconEffect::Colorize, 1.0, TQColor( r, g, b ), false );
 
         // Create new pixmap on the heap and add pointer to list
         m_glowPixmaps.append( temp );
