@@ -31,7 +31,7 @@
 #include "tooltip.h"         //baseclass
 #include "tracktooltip.h"
 
-#include <klistview.h>       //baseclass
+#include <tdelistview.h>       //baseclass
 #include <kurl.h>            //KURL::List
 #include <tqdir.h>            //stack allocated
 #include <tqpoint.h>          //stack allocated
@@ -39,8 +39,8 @@
 #include <tqstringlist.h>     //stack allocated
 #include <vector>            //stack allocated
 
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
 class PlaylistItem;
 class PlaylistEntry;
 class PlaylistLoader;
@@ -55,7 +55,7 @@ class Medium;
 /**
  * @authors Mark Kretschmann && Max Howell
  *
- * Playlist inherits KListView privately and thus is no longer a ListView
+ * Playlist inherits TDEListView privately and thus is no longer a ListView
  * Instead it is a part of PlaylistWindow and they interact in harmony. The change
  * was necessary as it is too dangerous to allow public access to PlaylistItems
  * due to the multi-threading environment.
@@ -76,10 +76,10 @@ class Medium;
 // AtomicString Index<KURL>::fieldString(const KURL &field);
 
 
-class Playlist : private KListView, public EngineObserver, public Amarok::ToolTipClient
+class Playlist : private TDEListView, public EngineObserver, public Amarok::ToolTipClient
 {
         Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         ~Playlist();
@@ -151,18 +151,18 @@ class Playlist : private KListView, public EngineObserver, public Amarok::ToolTi
         void customMenuClicked ( int id );
         bool removeCustomMenuItem( const TQString &submenu, const TQString &itemTitle );
 
-        void setFont( const TQFont &f ) { KListView::setFont( f ); } //made public for convenience
-        void unsetFont()               { KListView::unsetFont(); }
+        void setFont( const TQFont &f ) { TDEListView::setFont( f ); } //made public for convenience
+        void unsetFont()               { TDEListView::unsetFont(); }
 
-        PlaylistItem *firstChild() const { return static_cast<PlaylistItem*>( KListView::firstChild() ); }
-        PlaylistItem *lastItem()   const { return static_cast<PlaylistItem*>( KListView::lastItem() ); }
-        PlaylistItem *currentItem() const { return static_cast<PlaylistItem*>( KListView::currentItem() ); }
+        PlaylistItem *firstChild() const { return static_cast<PlaylistItem*>( TDEListView::firstChild() ); }
+        PlaylistItem *lastItem()   const { return static_cast<PlaylistItem*>( TDEListView::lastItem() ); }
+        PlaylistItem *currentItem() const { return static_cast<PlaylistItem*>( TDEListView::currentItem() ); }
 
         int  numVisibleColumns() const;
         TQValueList<int> visibleColumns() const;
         MetaBundle::ColumnMask getVisibleColumnMask() const;
         int  mapToLogicalColumn( int physical ) const; // Converts physical PlaylistItem column position to logical
-        TQString columnText( int c ) const { return KListView::columnText( c ); };
+        TQString columnText( int c ) const { return TDEListView::columnText( c ); };
         void setColumns( TQValueList<int> order, TQValueList<int> visible );
 
         /** Call this to prevent items being removed from the playlist, it is mostly for internal use only
@@ -171,8 +171,8 @@ class Playlist : private KListView, public EngineObserver, public Amarok::ToolTi
         void unlock();
 
         //reimplemented to save columns by name instead of index, to be more resilient to reorderings and such
-        void saveLayout(KConfig *config, const TQString &group) const;
-        void restoreLayout(KConfig *config, const TQString &group);
+        void saveLayout(TDEConfig *config, const TQString &group) const;
+        void restoreLayout(TDEConfig *config, const TQString &group);
 
         //AFT-related functions
         bool checkFileStatus( PlaylistItem * item );
@@ -323,13 +323,13 @@ class Playlist : private KListView, public EngineObserver, public Amarok::ToolTi
         void engineNewMetaData( const MetaBundle&, bool );
         void engineStateChanged( Engine::State, Engine::State = Engine::Empty );
 
-        /// KListView Overloaded functions
+        /// TDEListView Overloaded functions
         void contentsDropEvent     ( TQDropEvent* );
         void contentsDragEnterEvent( TQDragEnterEvent* );
         void contentsDragMoveEvent ( TQDragMoveEvent* );
         void contentsDragLeaveEvent( TQDragLeaveEvent* );
 
-        #ifdef PURIST //KListView imposes hand cursor so override it
+        #ifdef PURIST //TDEListView imposes hand cursor so override it
         void contentsMouseMoveEvent( TQMouseEvent *e ) { TQListView::contentsMouseMoveEvent( e ); }
         #endif
 
@@ -384,9 +384,9 @@ class Playlist : private KListView, public EngineObserver, public Amarok::ToolTi
         TQ_INT64       m_total; //for Favor Tracks
         bool          m_itemCountDirty;
 
-        KAction      *m_undoButton;
-        KAction      *m_redoButton;
-        KAction      *m_clearButton;
+        TDEAction      *m_undoButton;
+        TDEAction      *m_redoButton;
+        TDEAction      *m_clearButton;
 
         TQDir          m_undoDir;
         TQStringList   m_undoList;
